==> zither-1.1.13.tar.gz: zither_prj/apollon/monitor_insert.php <==
<?php
require("./total.inc");


session_start();
require("./ninsyou.inc");
if(0 > ninsyou_check(5)){
   exit;
   }



echo "<!DOCTYP:pserver:cvs@dhcvs.ms-n.com:/usr/home/cvsE HTML PUBLIC '-//W3C//DTD HTML 4.01 Transitional//EN'>";
echo "<HTML>";
echo "<HEAD>";
echo "<META name='GENERATOR' content='AmBuilder'>";
echo "<META http-equiv='Content-Type' content='text/html; charset=euc-jp'>";
        echo "<title>zither monitorring save info</title>";
echo "</head>";






$conn = Pg_connect("hostaddr='$pg_connect_ip' port='5432' dbname='zither' connect_timeout='8'");
if(!$conn){
   echo "not connection!<br>";
   exit;
   }


//  ƻ֥å̾ꥹȺ
$bname_count = 0;
$result = pg_query($conn, "select distinct(bname) from userblock;");
if(!$result){
   print("banem select , bud query\n");
   exit;
   }
$num = pg_num_rows($result);
if($num > 0){
   while($bname_count < $num){
      $bname_data[$bname_count] = rtrim(pg_fetch_Result($result, $bname_count, bname));
      $result1=pg_query($conn,"select distinct(cname) from userblock where bname='$bname_data[$bname_count]';");
      if(!$result1){
         print("bname , canem select , bud query\n");
         exit;
         }
      $num1 = pg_num_rows($result1);
      if($num1 > 0){
         $cname_data[$bname_count] = rtrim(pg_fetch_Result($result1, 0, cname));
         }
      $bname_count++;
      }
   }
else{
   print("NG ƻ֥å̵Ǥ \n");
   }
pg_free_result($result);
pg_free_result($result1);

pg_Close($conn);





print("</head>");
print("<body alink='#ff0000' bgcolor='$my_bgcolor' link='#0000ff' text='#000000' vlink='#000080'>\n");

print("<TABLE border='0' bgcolor='FFA500' cellspacing='3' cellpadding='0' width=100%>\n");
print("<tr><td align=left><font color='ffffff'><b>ƻ -> </b></font></td></tr>\n");

print("</table>\n");

print("<TABLE border=0 cellspacing=0 cellpadding=3 WIDTH=80% BGCOLOR=#e6e8fa>\n");
print("<FORM METHOD=GET ACTION='monitor_newedit.php' target='insert'>\n");

print("<tr><td>\n");
print("ƻοǤƻ֥å̾ꤷƺƤ<br>\n");
print("</td></tr>\n");

print("<tr><td>\n");
print("ƻ°<br>\n");
print("</td>\n");
print("<td>\n");
print("<select size=1 name=MONITOR>\n");
print("<option value=PORT>PORT or DHW\n");
print("<option value=COMAND>COMAND\n");
print("<option value=SNMP>SNMP\n");
print("</select>\n");
print("</td>\n");
print("</tr>\n");
print("<br>\n");

//print("<tr><td>\n");
//print("ƻ֥å̾<br>\n");
//print("</td>\n");
//print("<td>\n");
//print("<INPUT type='text' NAME=FREE4 size='24' value='NOT'>\n");
// print("</td></tr><br>\n");


echo "<tr><td>";
echo "ƻ֥å̾\n";
echo "</td><td>";
echo "<select size=1 name=FREE4>";
echo "<option value=>򤷤Ƥ";
for($select_count = 0; $select_count < $bname_count; $select_count++){
   echo "<option value=$bname_data[$select_count]>$bname_data[$select_count] ($cname_data[$select_count])";
   }
echo "</select>";
echo "</td></tr>";



print("<tr><td>\n");
print("Υܥ򲡤ȿڡ˰ưޤ<br>\n");
print("</td>\n");
print("<td>\n");
print("<input type=submit value='ڡ˰ưޤ'>\n");
print("</td></tr><br><br>\n");

print("</form>\n");
print("</table>\n");

?>

</body>
</html>

==> zither-1.1.15.tar.gz: zither_prj/apollon/monitor_insert.php <==
<?php
require("./total.inc");


session_start();
require("./ninsyou.inc");
if(0 > ninsyou_check(5)){
   exit;
   }



echo "<!DOCTYP:pserver:cvs@dhcvs.ms-n.com:/usr/home/cvsE HTML PUBLIC '-//W3C//DTD HTML 4.01 Transitional//EN'>";
echo "<HTML>";
echo "<HEAD>";
echo "<META name='GENERATOR' content='AmBuilder'>";
echo "<META http-equiv='Content-Type' content='text/html; charset=euc-jp'>";
        echo "<title>zither monitorring save info</title>";
echo "</head>";






$conn = Pg_connect("hostaddr='$pg_connect_ip' port='5432' dbname='zither' connect_timeout='8'");
if(!$conn){
   echo "not connection!<br>";
   exit;
   }


//  ƻ֥å̾ꥹȺ
$bname_count = 0;
$result = pg_query($conn, "select distinct(bname) from userblock;");
if(!$result){
   print("banem select , bud query\n");
   exit;
   }
$num = pg_num_rows($result);
if($num > 0){
   while($bname_count < $num){
      $bname_data[$bname_count] = enco_rtrim(pg_fetch_Result($result, $bname_count, bname));
      $result1=pg_query($conn,"select distinct(cname) from userblock where bname='$bname_data[$bname_count]';");
      if(!$result1){
         print("bname , canem select , bud query\n");
         exit;
         }
      $num1 = pg_num_rows($result1);
      if($num1 > 0){
         $cname_data[$bname_count] = enco_rtrim(pg_fetch_Result($result1, 0, cname));
         }
      $bname_count++;
      }
   }
else{
   print("NG ƻ֥å̵Ǥ \n");
   }
pg_free_result($result);
pg_free_result($result1);

pg_Close($conn);





print("</head>");
print("<body alink='#ff0000' bgcolor='$my_bgcolor' link='#0000ff' text='#000000' vlink='#000080'>\n");

print("<TABLE border='0' bgcolor='FFA500' cellspacing='3' cellpadding='0' width=100%>\n");
print("<tr><td align=left><font color='ffffff'><b>ƻ -> </b></font></td></tr>\n");

print("</table>\n");

print("<TABLE border=0 cellspacing=0 cellpadding=3 WIDTH=80% BGCOLOR=#e6e8fa>\n");
print("<FORM METHOD=GET ACTION='monitor_newedit.php' target='insert'>\n");

print("<tr><td>\n");
print("ƻοǤƻ֥å̾ꤷƺƤ<br>\n");
print("</td></tr>\n");

print("<tr><td>\n");
print("ƻ°<br>\n");
print("</td>\n");
print("<td>\n");
print("<select size=1 name=MONITOR>\n");
print("<option value=PORT>PORT or DHW\n");
print("<option value=COMAND>COMAND\n");
print("<option value=SNMP>SNMP\n");
print("</select>\n");
print("</td>\n");
print("</tr>\n");
print("<br>\n");

//print("<tr><td>\n");
//print("ƻ֥å̾<br>\n");
//print("</td>\n");
//print("<td>\n");
//print("<INPUT type='text' NAME=FREE4 size='24' value='NOT'>\n");
// print("</td></tr><br>\n");


echo "<tr><td>";
echo "ƻ֥å̾\n";
echo "</td><td>";
echo "<select size=1 name=FREE4>";
echo "<option value=>򤷤Ƥ";
for($select_count = 0; $select_count < $bname_count; $select_count++){
   echo "<option value=$bname_data[$select_count]>$bname_data[$select_count] ($cname_data[$select_count])";
   }
echo "</select>";
echo "</td></tr>";



print("<tr><td>\n");
print("Υܥ򲡤ȿڡ˰ưޤ<br>\n");
print("</td>\n");
print("<td>\n");
print("<input type=submit value='ڡ˰ưޤ'>\n");
print("</td></tr><br><br>\n");

print("</form>\n");
print("</table>\n");

?>

</body>
</html>
